# converter between mib-name and dot-formation
# 
#   input 
#          parm1(ϊt@C)
#          parm2(SystemwalkerCXg[fBNg)
# 
#      ϐ  objname    c  Sobj-namelist
#                objdot     c  Sobjidlist
# 
#                               



##################################################################
proc d2n {input} {

	global objname
	global objdot

	regsub -all {\.} $input " " idlist
	set numofids [llength $idlist]
	set index -1
	for { set i $numofids } { $i > 0 } { incr i -1} {
		set temptarget ""
		for { set j 0 } { $j < $i } { incr j } {
			if {$j!=0} { append temptarget "." }
			append temptarget [lindex $idlist $j]
		}
		set index [lsearch -exact $objdot $temptarget]
		if { $index > 0 } break 
	}
	if { $index > 0 } {
		set result [lindex $objname $index]
		for { set j $i } { $j < $numofids } { incr j } {
			append result "."
			append result [lindex $idlist $j]
		}
		return $result 
	} else {
		return "ERROR" 
	}
}


##################################################################
proc n2d {input} {

	global objname
	global objdot

	set index [ string first "." $input ]
	if { $index < 0 } {
		set tindex [lsearch $objname $input]
		if { $tindex > 0 } {
			set result [lindex $objdot $tindex]
		} else {
			set result "ERROR" 
		}
	} else {
		set namepart [string range $input 0 [expr $index-1 ] ]
		set dotpart  [string range $input $index end]
		if { [regexp {^[0-9\.]*$} $dotpart ] == 0 } {
			set result "ERROR" 
		} else {
			set tindex [lsearch $objname $namepart]
			if { $tindex > 0 } {
				set result [lindex $objdot $tindex]
				set alldot $result
				append alldot $dotpart				
				set result $alldot
			} else {
				set result "ERROR" 
			}
		}
	}

	return $result

}


##################################################################
# main process
	variable objname 
	variable objdot 

	set objname ""
	set objdot  ""
	
# Operands check
	if { $argc != 2 } {
		puts stderr "ERROR Invalid parameter -- source.bat syswk-install-dir"
		exit
	}
	set SourceFileName [lindex $argv 0]
	set SYSWK [lindex $argv 1]\\mpwalker.dm\\mpnetmgr\\bin\\
	set MibDir [lindex $argv 1]\\mpwalker.dm\\mib
		
	if { [ file readable $SourceFileName ] == 0 } {
		puts stderr "ERROR $SourceFileName is not readable"
		exit
	}
	if { [ file exist $SYSWK ] == 0 } {
		puts stderr "ERROR $SYSWK is not exist"
		exit
	}

	if { [file exists $MibDir] == 0 } {
		puts stderr "directory ${MibDir} does not exist"
		exit
	}
	# path separaters are converted platform separeter to tcl separeter
	set MibDir [file join ${MibDir}]

	# getting mib file list
	set mibfiles [glob -path ${MibDir}/ {*.[mM][iI][bB]}]

	foreach file ${mibfiles} {
		# Read xxx.MIB file,
		# and initialise obj name list and obj dot-format-id list.
		set mfileid [open "${file}" r]
		while { [eof ${mfileid}] == 0 } {
			gets ${mfileid} record
			regsub -all "," ${record} " " record
			if { [lsearch -exact $objname [lindex ${record} 0] ] } {
				lappend objname [lindex ${record} 0]
				lappend objdot  [lindex ${record} 1]
			}
		}
		close ${mfileid}
	}

# Bat file conbert
	set infileid  [open $SourceFileName r]
	while { [eof $infileid]==0 } {
		gets $infileid record
		if { [ regexp "^snmptrap" $record ] == 0 } {
			puts stdout $record
			continue
		}
		for {set i 1} { $i < [llength $record] } { incr i} {
			if { [ lindex $record $i ] == "-m" } {
				incr i
				set record [ lreplace $record $i $i [ n2d [lindex $record $i] ] ]
			}
		}
		puts stdout $SYSWK$record
	}
	close $infileid



